<?php
/**
 * Plugin Name: Bulk Order Form Category Picker
 * Plugin URI: https://wpovernight.com
 * Description: Add the [wcbulkorder_category_picker] shortcode to your page or post to create a category picker for the Bulk Order Form plugin.
 * Version: 1.0
 * Author: Jeremiah Prummer
 * Author URI: https://wpovernight.com
 * License: GPL2
 */
class WCBulkOrder_Category_Picker {
	
	/**
	 * Construct.
	 */
	public function __construct() {
		// Exclude the products
		add_shortcode('wcbulkorder_category_picker', array( &$this, 'wcbulkorder_category_picker' ) );
		// Init updater data
		$this->item_name	= 'Bulk Order Form Category Picker';
		$this->file			= __FILE__;
		$this->license_slug	= 'bulkorderformcategorypicker_license';
		$this->version		= '1.0';
		$this->author		= 'Jeremiah Prummer';
		add_action( 'init', array( &$this, 'load_updater' ), 0 );
	}
	/**
	 * Run the updater scripts from the Sidekick
	 * @return void
	 */
	public function load_updater() {
		// Check if sidekick is loaded
		if (class_exists('WPO_Updater')) {
			$this->updater = new WPO_Updater( $this->item_name, $this->file, $this->license_slug, $this->version, $this->author );
		}
	}
	function wcbulkorder_category_picker($atts){
		extract( shortcode_atts( array(
			'exclude' => ''
		), $atts ) );
		$excluded = !empty($exclude) ? explode(',', $exclude) : array();
		$categories = get_terms('product_cat');
		$html = '<select id="category-picker">';
		$html .= '<option value="">Select A Category</option>';
		foreach($categories as $cat){
			if(!in_array($cat->term_id, $excluded)){
				$html .= '<option value="'.$cat->term_id.'">'.$cat->name.'</option>';
			}
		}
		$html .= '<option value="">All Categories</option>';
		$html .='</select>';
		add_action('wp_footer', array(&$this,'wcbulkorder_category_picker_js'));
		return $html;
	}
	function wcbulkorder_category_picker_js(){
		?>
		<script>
			jQuery( document ).ready(function( $ ) {
				$('select#category-picker').click(function(){
					WCBulkOrder.category = $('#category-picker').val();
					$('#BulkOrderForm').attr('category',$('#category-picker').val());
				});
				$('select#category-picker').bind('touchstart', function(event){
					WCBulkOrder.category = $('#category-picker').val();
					$('#BulkOrderForm').attr('category',$('#category-picker').val());
				});
			});
		</script>
		<?php
	}
}
$WCBulkOrder_Category_Picker = new WCBulkOrder_Category_Picker();